@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Nestoria::Search::Result;
 {
-  $WebService::Nestoria::Search::Result::VERSION = '1.021005';
+  $WebService::Nestoria::Search::Result::VERSION = '1.022000';
 }
 
 =head1 NAME
@@ -12,7 +12,7 @@ WebService::Nestoria::Search::Result - Container object for a WebService::Nestor
 
 =head1 VERSION
 
-version 1.021005
+version 1.022000
 
 Contains all the information received about a single property listing and many functions for outputting the information.
 
@@ -55,6 +55,7 @@ as follows:
     get_bedroom_number
     get_bathroom_number
     get_room_number
+    get_floor
     get_size
     get_size_unit
     get_land_size
@@ -95,6 +96,7 @@ sub get_summary                   { shift->{data}{listing}{summary}
 sub get_bedroom_number            { shift->{data}{listing}{bedroom_number}                }
 sub get_bathroom_number           { shift->{data}{listing}{bathroom_number}               }
 sub get_room_number               { shift->{data}{listing}{room_number}                   }
+sub get_floor                     { shift->{data}{listing}{floor}                         }
 sub get_size                      { shift->{data}{listing}{size}                          }
 sub get_size_unit                 { shift->{data}{listing}{size_unit}                     }
 sub get_land_size                 { shift->{data}{listing}{land_size}                     }
@@ -141,6 +143,7 @@ Returns a hashref containing the details of the listing with keys exactly as the
         'bedroom_number' => '4',
         'thumb_height' => '60',
         'datasource_name' => 'PropertyFinder'
+        'floor' => '2',
     };
 
 =cut
